//
//  MADContext.h
//  MADCore
//
//  Created by JustinLu on 9/14/17.
//  Copyright © 2017 Chengming Lu. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface MADContext : NSObject {
    id rawContext;
}

/**

 
 自定义报文加解密
  包含两种类型，A：只操作body；B：需要借助于url/header/body
  如果使用A类型：
  encryptionsCallBack  输入端为需要加密的body，输出端为加密后的body；
  decryptionsCallBack  输入端为待解密的body，输出端为解密后的body；
  如果使用B类型：
  encryptionsCallBack 输入端为body，输出为{Url:"",Header:{需要添加的key-vlue},Body:"加密后的body"}
  decryptionsCallBack  输入端为{Url:"",Header:{},Body:""}，输出端为解密后的body；
 */
@property (nonatomic, copy) NSData *(^decryptionsCallBack)(NSData *p0);
@property (nonatomic, copy) NSData *(^encryptionsCallBack)(NSData *p0);


/*
 Resource
 + 作用：用于获取资源文件
 + 入参：
     + url：字符串类型，为文件url请求地址
 + 返回参数：
     + 字节组，为文件内容

 Send
 + 作用：发送交易请求
 + 入参：
     + 字节组json类型,其格式为`{"Url":"","Header":{},"Body":""}`
 + 返回：
     + 字节组json类型,`{"StatusCode":1,"Header":{},"Body":""}`
 **/
@property (nonatomic, copy) NSData *(^resourceCallBack)(NSString *p0);
@property (nonatomic, copy) NSData *(^sendCallBack)(NSData *p0);

 
 
@property (nonatomic, strong) id rawContext;

- (id)initWithWorkerContext:(id)ctx;
- (void)next;
- (void)finish;
- (void)finishTo:(NSString *)stageid;
- (void)finishWithReturnValue:(NSString*)data;
- (NSString*)getReturnValue;
- (NSString*)extra;
- (NSString*)getParam:(NSString*)key;
- (void)launchStage:(NSString*)stageid;
- (void)replaceStage:(NSString*)stageid;
- (void)shutdown;
- (NSString*)secureGetString:(NSString*)key;
- (void)secureSetString:(NSString*)key value:(NSString*)value;
- (NSString*)secureGetSm4:(NSString*)key;
- (void)secureSetSm4:(NSString* )key value:(NSString* )value;
- (NSString*)sessionGetString:(NSString*)key;
- (void)sessionSetString:(NSString*)key value:(NSString*)value;
- (int)setToken:(NSString*)token;
- (void)clearToken;
- (int)checkToken;
- (NSString*)getTokenClaimString:(NSString*)key;
- (NSString*)getTimestamp;
- (void)setTimestamp:(NSString*)timestr;
- (NSString*)envGet:(NSString*)key;
- (int)handleQRCode:(NSString*)url;
- (NSString*)hashSHA256:(NSString*)plaintext;
- (NSString*)getMappedFileUrl:(NSString*)file;
- (NSString *)deviceSignature;
- (NSString*)getTokenClaimKeys;
- (long)refreshRepo:(NSString*)repoid;
- (long)refreshCentral;
- (long)isStageAvailable:(NSString*)stageid;
- (NSString*)getMappedUrl:(NSString*)path;
- (NSString*)getEnvKeys;
- (void)switchEnv:(NSString*)key;
- (NSString *)getRegistryString:(NSString*)key;
- (NSString*)proxyGetAddress;
- (NSString*)proxyGetHost;
- (long)proxyGetPort;
- (long)handleGray:(NSString*)userid;
- (void)grayChooice:(NSString* _Nullable)x;
//- (long)registryCustomEncryption;
// type == 3 会把url/header/body通过block暴漏；其他的都是暴漏body
- (long)registryCustomEncryption:(NSInteger) type;
- (long)cancelCustomEncryption;
////注册Communication协议
//- (void)registryCommunication;
//获取当前场景栈名称
- (NSString*)navigationGetCurrent;
//清除本地化持久化数据
- (void)clearData;
//清除所有资源数据缓存
- (BOOL)clearCache;
//获取客群规则
- (NSString*)getUserGroup;

@end
